@@ -25,7 +25,7 @@ import click
 from bump_release import helpers
 
 # region Globals
-__version__ = VERSION = "0.9.10"
+__version__ = VERSION = "0.10.2"
 RELEASE_FILE: Optional[Path] = None
 RELEASE_CONFIG: Optional[ConfigParser] = None
 
@@ -60,12 +60,7 @@ RELEASE_CONFIG: Optional[ConfigParser] = None
 )
 @click.version_option(version=__version__)
 @click.argument("release")
-def bump_release(
-    release: str,
-    release_file: Optional[str] = None,
-    dry_run: bool = False,
-    debug: bool = False,
-) -> int:
+def bump_release(release: str, release_file: Optional[str] = None, dry_run: bool = False, debug: bool = False) -> int:
     """
     Update release numbers in various places, according to a release.ini file places at the project root.
 
@@ -129,7 +124,7 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Updates the main project (DJANGO_SETTINGS_MODULE file for django projects, __init__.py file...)
     try:
-        new_row = update_main_file(version=version, dry_run=dry_run)
+        new_row = update_main_file(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(f"process_update() `main_project`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
@@ -138,7 +133,7 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Updates sonar-scanner properties
     try:
-        new_row = update_sonar_properties(version=version, dry_run=dry_run)
+        new_row = update_sonar_properties(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(f"process_update() `sonar`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
@@ -147,7 +142,7 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Updates setup.py file
     try:
-        new_row = update_setup_file(version=version, dry_run=dry_run)
+        new_row = update_setup_file(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(f"process_update() `setup`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
@@ -156,7 +151,7 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Update setup.cfg file
     try:
-        new_row = update_setup_cfg_file(version=version, dry_run=dry_run)
+        new_row = update_setup_cfg_file(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(f"process_update() `setup`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
@@ -165,7 +160,7 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Updates sphinx file
     try:
-        new_row = update_docs_conf(version=version, dry_run=dry_run)
+        new_row = update_docs_conf(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(f"process_update() `docs`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
@@ -174,7 +169,8 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Updates node packages file
     try:
-        new_row = update_node_package(version=version, dry_run=dry_run)
+        logging.debug("process_update() `node_module`")
+        new_row = update_node_package(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(
                 f"process_update() `node`: new_row = {new_row}",
@@ -185,40 +181,40 @@ def process_update(release_file: Path, release: str, dry_run: bool, debug: bool
 
     # region Updates YAML file
     try:
-        new_row = update_ansible_vars(version=version, dry_run=dry_run)
+        new_row = update_ansible_vars(version=version, base_path=release_file.parent, dry_run=dry_run)
         if new_row is not None:
             logging.debug(f"process_update() `ansible`: new_row = {new_row.strip()}")
     except helpers.NothingToDoException as e:
         logging.warning(f"process_update() No release section for `ansible`: {e}")
     # endregion
 
+    # region Updates pyproject.toml file
+    try:
+        new_row = update_pyproject(version=version, base_path=release_file.parent, dry_run=dry_run)
+        if new_row is not None:
+            logging.debug(f"process_update() `pyproject.toml`: new_row = {new_row.strip()}")
+    except helpers.NothingToDoException as e:
+        logging.warning(f"process_update() No release section for `pyproject.toml`: {e}")
+    except helpers.UpdateException:  # noqa: E722
+        logging.exception("process_update() `pyproject.toml`: UpdateException - tomli / tomli_w might be missing")
+
+    # endregion Updates pyproject.toml file
+
     # region Updates the release.ini file with the new release number
     new_row = update_release_ini(path=release_file, version=version, dry_run=dry_run)
     if new_row is not None:
         logging.warning(f"process_update() `release.ini`: new_row = {new_row.strip()}")
     # endregion
 
-    # region Updates pyproject.toml file
-    try:
-        new_row = update_pyproject(version=version, dry_run=dry_run)
-        if new_row is not None:
-            logging.debug(f"process_update() `pyproject.toml`: new_row = {new_row.strip()}")
-    except helpers.NothingToDoException as e:
-        logging.warning(f"process_update() No release section for `pyproject.toml`: {e}")
-    except helpers.UpdateException:  # noqa: E722
-        logging.exception("process_update() `pyproject.toml`: UpdateException - tomli / tomli_w might be missing")
-        return 4
-
-    # endregion Updates pyproject.toml file
-
     return 0
 
 
-def update_main_file(version: helpers.VersionNumber, dry_run: bool = True) -> Optional[str]:
+def update_main_file(version: helpers.VersionNumber, base_path: Path, dry_run: bool = True) -> Optional[str]:
     """
     Updates the main django settings file, or a python script with a __init__.py file.
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
@@ -227,10 +223,8 @@ def update_main_file(version: helpers.VersionNumber, dry_run: bool = True) -> Op
         raise helpers.NothingToDoException("No `main_project` section in release.ini file")
 
     try:
-        _path = RELEASE_CONFIG["main_project"].get("path")
-        if _path is None:
-            raise helpers.NothingToDoException("No action to perform for main project: No path provided.")
-        path = Path(_path)
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("main_project", "path"), release_file_path=base_path)
+        logging.debug(f"update_main_file() path = {path}")
         pattern = RELEASE_CONFIG["main_project"].get("pattern", "").strip('"') or helpers.MAIN_PROJECT_PATTERN
         template = RELEASE_CONFIG["main_project"].get("template", "").strip('"') or helpers.MAIN_PROJECT_TEMPLATE
     except configparser.Error as e:
@@ -238,11 +232,12 @@ def update_main_file(version: helpers.VersionNumber, dry_run: bool = True) -> Op
     return helpers.update_file(path=path, pattern=pattern, template=template, version=version, dry_run=dry_run)
 
 
-def update_setup_file(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
+def update_setup_file(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
     """
     Updates the setup.py file.
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
@@ -251,8 +246,8 @@ def update_setup_file(version: helpers.VersionNumber, dry_run: bool = False) ->
         raise helpers.NothingToDoException("No `setup` section in release.ini file")
 
     try:
-        _path = RELEASE_CONFIG["setup"].get("path")
-        path = Path(_path)
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("setup", "path"), release_file_path=base_path)
+        logging.debug(f"update_setup_file() path = {path}")
         pattern = RELEASE_CONFIG["setup"].get("pattern", "").strip('"') or helpers.SETUP_PATTERN
         template = RELEASE_CONFIG["setup"].get("template", "").strip('"') or helpers.SETUP_TEMPLATE
 
@@ -261,11 +256,12 @@ def update_setup_file(version: helpers.VersionNumber, dry_run: bool = False) ->
     return helpers.update_file(path=path, pattern=pattern, template=template, version=version, dry_run=dry_run)
 
 
-def update_setup_cfg_file(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
+def update_setup_cfg_file(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
     """
     Update the setup.cfg file.
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
@@ -274,8 +270,8 @@ def update_setup_cfg_file(version: helpers.VersionNumber, dry_run: bool = False)
         raise helpers.NothingToDoException("No `setup_cfg` section in release.ini file")
 
     try:
-        _path = RELEASE_CONFIG["setup_cfg"].get("path")
-        path = Path(_path)
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("setup_cfg", "path"), release_file_path=base_path)
+        logging.debug(f"update_setup_cfg_file() path = {path}")
         pattern = RELEASE_CONFIG["setup_cfg"].get("pattern", "").strip('"') or helpers.SETUP_CFG_PATTERN
         template = RELEASE_CONFIG["setup_cfg"].get("template", "").strip('"') or helpers.SETUP_CFG_TEMPLATE
 
@@ -284,11 +280,12 @@ def update_setup_cfg_file(version: helpers.VersionNumber, dry_run: bool = False)
     return helpers.update_file(path=path, pattern=pattern, template=template, version=version, dry_run=dry_run)
 
 
-def update_sonar_properties(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
+def update_sonar_properties(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
     """
     Updates the sonar-project.properties file with the new release number
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
@@ -297,8 +294,8 @@ def update_sonar_properties(version: helpers.VersionNumber, dry_run: bool = Fals
         raise helpers.NothingToDoException("No `sonar` section in release.ini file")
 
     try:
-        _path = RELEASE_CONFIG["sonar"].get("path")
-        path = Path(_path)
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("sonar", "path"), release_file_path=base_path)
+        logging.debug(f"update_sonar_properties() path = {path}")
         pattern = RELEASE_CONFIG["sonar"].get("pattern", "").strip('"') or helpers.SONAR_PATTERN
         template = RELEASE_CONFIG["sonar"].get("template", "").strip('"') or helpers.SONAR_TEMPLATE
     except configparser.Error as e:
@@ -306,11 +303,12 @@ def update_sonar_properties(version: helpers.VersionNumber, dry_run: bool = Fals
     return helpers.update_file(path=path, pattern=pattern, template=template, version=version, dry_run=dry_run)
 
 
-def update_docs_conf(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
+def update_docs_conf(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
     """
     Updates the Sphinx conf.py file with the new release number
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
@@ -319,8 +317,8 @@ def update_docs_conf(version: helpers.VersionNumber, dry_run: bool = False) -> O
         raise helpers.NothingToDoException("No `docs` section in release.ini file")
 
     try:
-        _path = RELEASE_CONFIG["docs"].get("path")
-        path = Path(_path)
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("docs", "path"), release_file_path=base_path)
+        logging.debug(f"update_docs_conf() path = {path}")
 
         pattern_release = RELEASE_CONFIG["docs"].get("pattern_release", "").strip('"') or helpers.DOCS_RELEASE_PATTERN
         template_release = RELEASE_CONFIG["docs"].get("template_release", "").strip('"') or helpers.DOCS_RELEASE_FORMAT
@@ -347,40 +345,77 @@ def update_docs_conf(version: helpers.VersionNumber, dry_run: bool = False) -> O
     return str(update_release) + str(update_version)
 
 
-def update_node_package(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
+def update_node_package(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
     """
     Updates the nodejs package file with the new release number
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
     assert RELEASE_CONFIG is not None
     try:
-        path = Path(RELEASE_CONFIG.get("node", "path"))
-        key = RELEASE_CONFIG.get("node", "key", fallback=helpers.NODE_KEY)  # noqa
+        if "node" in RELEASE_CONFIG:
+            path = helpers.resolve_path(path=RELEASE_CONFIG.get("node", "path"), release_file_path=base_path)
+        elif "node_module" in RELEASE_CONFIG:
+            path = helpers.resolve_path(path=RELEASE_CONFIG.get("node_module", "path"), release_file_path=base_path)
+        else:
+            raise helpers.NothingToDoException("No `node` or `node_module` section in release.ini file")
+        logging.debug(f"update_node_package() path = {path}")
+        key = RELEASE_CONFIG.get("node_module", "key", fallback=helpers.NODE_KEY)  # noqa
     except configparser.Error as e:
         raise helpers.NothingToDoException("No action to perform for node packages file", e)
-    return helpers.update_node_packages(path=path, version=version, key=key, dry_run=dry_run)
+    return helpers.update_json_file(path=path, version=version, key=key, dry_run=dry_run)
 
 
-def update_ansible_vars(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
+def update_ansible_vars(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
     """
     Updates the ansible project variables file with the new release number
 
     :param version: Release number tuple (major, minor, release)
+    :param base_path: Base search path
     :param dry_run: If `True`, no operation performed
     :return: changed string
     """
     assert RELEASE_CONFIG is not None
     try:
-        path = Path(RELEASE_CONFIG.get("ansible", "path"))
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("ansible", "path"), release_file_path=base_path)
+        logging.debug(f"update_ansible_vars() path = {path}")
         key = RELEASE_CONFIG.get("ansible", "key", fallback=helpers.ANSIBLE_KEY)  # noqa
     except configparser.Error as e:
         raise helpers.NothingToDoException("No action to perform for ansible file", e)
     return helpers.updates_yaml_file(path=path, version=version, key=key, dry_run=dry_run)
 
 
+def update_pyproject(version: helpers.VersionNumber, base_path: Path, dry_run: bool = False) -> Optional[str]:
+    """
+    Updates the pyproject.toml file with the new release number
+
+    :param version: release number, as (<major>, <minor>, <release>)
+    :param base_path: Base search path
+    :param dry_run: If `True`, the operation WILL NOT be performed
+    :return: Updated lines
+    """
+    assert RELEASE_CONFIG is not None
+    try:
+        path = helpers.resolve_path(path=RELEASE_CONFIG.get("pyproject", "path"), release_file_path=base_path)
+        logging.debug(f"update_pyproject() path = {path}")
+        key = RELEASE_CONFIG.get("pyproject", "key", fallback=helpers.PYPROJECT_KEY)  # noqa
+    except KeyError as ke:
+        raise helpers.NothingToDoException("No pyproject key found in ini file for pyproject.toml file", ke)
+    except configparser.Error as e:
+        raise helpers.NothingToDoException("No action to perform for pyproject.toml file", e)
+
+    # Update pyproject.toml file
+    return helpers.update_toml_file(
+        path=path,
+        version=version,
+        key=key,
+        dry_run=dry_run,
+    )
+
+
 def update_release_ini(path: Path, version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
     """
     Updates the release.ini file with the new release number
@@ -397,29 +432,3 @@ def update_release_ini(path: Path, version: helpers.VersionNumber, dry_run: bool
         version=version,
         dry_run=dry_run,
     )
-
-
-def update_pyproject(version: helpers.VersionNumber, dry_run: bool = False) -> Optional[str]:
-    """
-    Updates the pyproject.toml file with the new release number
-
-    :param version: release number, as (<major>, <minor>, <release>)
-    :param dry_run: If `True`, the operation WILL NOT be performed
-    :return: Updated lines
-    """
-    assert RELEASE_CONFIG is not None
-    try:
-        path = Path(RELEASE_CONFIG.get("pyproject", "path"))
-        key = RELEASE_CONFIG.get("pyproject", "key", fallback=helpers.PYPROJECT_KEY)  # noqa
-    except KeyError as ke:
-        raise helpers.NothingToDoException("No pyproject key found in ini file for pyproject.toml file", ke)
-    except configparser.Error as e:
-        raise helpers.NothingToDoException("No action to perform for pyproject.toml file", e)
-
-    # Update pyproject.toml file
-    return helpers.update_toml_file(
-        path=path,
-        version=version,
-        key=key,
-        dry_run=dry_run,
-    )
