@@ -168,7 +168,7 @@ def update_file(
     raise UpdateException(f"An error has append on updating release for file {path}")
 
 
-def update_node_packages(
+def update_json_file(
     path: Path,
     version: VersionNumber,
     key: str = NODE_KEY,
@@ -194,15 +194,14 @@ def update_node_packages(
                 package_file.write(updated)
         return updated
     except IOError as ioe:
-        raise UpdateException(f"update_node_packages() Unable to perform {package_file} update: {ioe}")
+        raise UpdateException(f"update_json_file() Unable to perform {package_file} update: {ioe}")
 
 
 class MyYAML(YAML):
-    """
-    Wrapper around ruamel.yaml to output directly strings
-    """
+    """Wrapper around ruamel.yaml to output strings directly."""
 
     def dump(self, data, stream=None, **kw):
+        """Dump the data to the stream."""
         inefficient = False
         if stream is None:
             inefficient = True
@@ -230,13 +229,18 @@ def updates_yaml_file(
     yaml = MyYAML()
     with path.open(mode="r") as vars_file:
         document = yaml.load(vars_file)
-    node = document
+    internal_dict_value = document
     split_key = key.split(".")
-    for _key in split_key:
-        if _key == split_key[-1] and not dry_run:
-            node.update({_key: str(version)})
-        node = node.get(_key)
-    logging.debug(f"updates_yml_file({vars_file}) node value = {node}")
+    print(f"DEBUG: {split_key=}")
+    if len(split_key) == 1:
+        internal_dict_value.update({key: str(version)})
+    else:
+        for _key in split_key:
+            internal_dict_value = internal_dict_value.get(_key)
+            if internal_dict_value and _key == split_key[-1]:
+                internal_dict_value = str(version)
+    logging.debug(f"updates_yml_file({vars_file}) node value = {internal_dict_value}")
+    # Save the content
     new_content = yaml.dump(document)
     if not dry_run:
         with path.open(mode="w") as vars_file:
@@ -287,3 +291,20 @@ class NothingToDoException(UpdateException):
     """
 
     pass
+
+
+def resolve_path(path: str, release_file_path: Path) -> Path:
+    """
+    Resolve a path to a `Path` object.
+    """
+    assert path, "A path must be provided"
+    assert release_file_path, "A release file path must be provided"
+
+    _path = Path(path)
+    if _path.is_absolute():
+        return _path.resolve()
+    else:
+        if release_file_path.is_dir():
+            return release_file_path.joinpath(_path).resolve()
+        else:
+            return release_file_path.parent.joinpath(_path).resolve()
